@@ -13,7 +13,24 @@ def nestedShit(pureScript, fill, prevPageIndex, prevContentIndex, prevSceneIndex
                     if "timestamp" in scene:
                         return pureScript
                     else:
-                        scene["duration"] = fill
+                        if (
+                    scene["type"] != "ACTION"
+                    or (
+                        scene["type"] == "ACTION"
+                        and len(scene["content"]) > 0
+                        or (
+                            len(scene["content"]) == 0
+                            and "CONTINUED" not in scene["content"][0]["text"]
+                        )
+                    )
+                ) and (
+                            scene["type"] != "TRANSITION"
+                            or scene["type"] == "TRANSITION"
+                            and "CONTINUED" not in scene["content"]["text"]
+                        ):
+                            scene["duration"] = fill
+                        else:
+                            scene["duration"] = 0.0
 
                     prevSceneIndex += 1
                 prevSceneIndex = 0
@@ -75,7 +92,23 @@ def fillTimestamps(pureScript):
                     prevPageIndex = pageIndex
                     prevContentIndex = contentIndex
                     prevSceneIndex = sceneIndex + 1
-                else:
+                elif (
+                    scene["type"] != "ACTION"
+                    or (
+                        scene["type"] == "ACTION"
+                        and len(scene["content"]) > 0
+                        or (
+                            len(scene["content"]) == 0
+                            and "CONTINUED" not in scene["content"][0]["text"]
+                        )
+                    )
+                ) and (
+                    scene["type"] != "TRANSITION"
+                    or (
+                        scene["type"] == "TRANSITION"
+                        and "CONTINUED" not in scene["content"]["text"]
+                    )
+                ):
                     countInBetween += 1
 
                 sceneIndex += 1
